@@ -26,12 +26,11 @@ standard RFC headers.
 
 from __future__ import absolute_import
 
+import socket
 import uuid
 from time import strftime, gmtime, localtime
 from math import floor
 
-from gevent.socket import getfqdn
-
 from slimta.core import __version__ as VERSION
 from . import QueuePolicy
 
@@ -68,12 +67,12 @@ class AddMessageIdHeader(QueuePolicy):
     adding it if it does not exist.
 
     :param hostname: The hostname to use in the generated headers. By default,
-                     :func:`~gevent.socket.getfqdn()` is used.
+                     :func:`~socket.getfqdn()` is used.
 
     """
 
     def __init__(self, hostname=None):
-        self.hostname = hostname or getfqdn()
+        self.hostname = hostname or socket.getfqdn()
 
     def apply(self, envelope):
         if 'message-id' not in envelope.headers:
@@ -130,9 +129,7 @@ class AddReceivedHeader(QueuePolicy):
 
         data = ' '.join(parts) + '; ' + date
 
-        # Python does not provide header prepending, so this is a bit of a hack.
-        # Works in Python 2.7.3.
-        envelope.headers._headers.insert(0, ('Received', data))
+        envelope.prepend_header('Received', data)
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
