@@ -31,22 +31,21 @@ from __future__ import absolute_import
 import time
 import bisect
 import collections
-from itertools import repeat, chain
+from itertools import repeat
 
 import gevent
 from gevent import Greenlet
-from gevent.event import Event
+from gevent.event import Event  # type: ignore
 from gevent.lock import Semaphore
 from gevent.pool import Pool
-import six
-from six.moves import map
 
-from slimta.logging import log_exception
+from slimta import logging
 from slimta.core import SlimtaError
 from slimta.relay import PermanentRelayError, TransientRelayError
 from slimta.smtp.reply import Reply
 from slimta.bounce import Bounce
 from slimta.policy import QueuePolicy
+from slimta.util.pycompat import map
 
 __all__ = ['QueueError', 'Queue', 'QueueStorage']
 
@@ -322,10 +321,10 @@ class Queue(Greenlet):
         envelopes = self._run_policies(envelope)
         ids = self._pool_imap('store', self.store.write, envelopes,
                               repeat(now))
-        results = list(six.moves.zip(envelopes, ids))
+        results = list(zip(envelopes, ids))
         for env, id in results:
             if not isinstance(id, BaseException):
-                if self.relay:
+                if self.relay and id not in self.active_ids:
                     self.active_ids.add(id)
                     self._pool_spawn('relay', self._attempt, id, env, 0)
             elif not isinstance(id, QueueError):
@@ -390,7 +389,7 @@ class Queue(Greenlet):
         except PermanentRelayError as e:
             self._perm_fail(id, envelope, e.reply)
         except Exception as e:
-            log_exception(__name__)
+            logging.log_exception(__name__)
             reply = Reply('450', '4.0.0 Unhandled delivery error: '+str(e))
             self._pool_spawn('store', self._retry_later, id, envelope, reply)
             raise
@@ -435,21 +434,22 @@ class Queue(Greenlet):
             envelope, attempts = self.store.get(id)
         except KeyError:
             return
-        self.active_ids.add(id)
-        self._pool_spawn('relay', self._attempt, id, envelope, attempts)
+        if id not in self.active_ids:
+            self.active_ids.add(id)
+            self._pool_spawn('relay', self._attempt, id, envelope, attempts)
 
     def _check_ready(self, now):
         last_i = 0
         for i, entry in enumerate(self.queued):
-            timestamp, id = entry
+            timestamp, entry_id = entry
             if now >= timestamp:
-                self._pool_spawn('store', self._dequeue, id)
+                self._pool_spawn('store', self._dequeue, entry_id)
                 last_i = i+1
             else:
                 break
         if last_i > 0:
             self.queued = self.queued[last_i:]
-            self.queued_ids = set([id for timestamp, id in self.queued])
+            self.queued_ids = set([id for _, id in self.queued])
 
     def _wait_store(self):
         while True:
