@@ -27,16 +27,24 @@ be another SMTP hop, or it could be implemented as a final delivery mechanism.
 from __future__ import absolute_import
 
 from slimta.core import SlimtaError
+from slimta.smtp.reply import Reply
 from slimta.policy import RelayPolicy
 
 __all__ = ['PermanentRelayError', 'TransientRelayError', 'Relay']
 
 
 class RelayError(SlimtaError):
+
+    _default_code = None
+    _default_esc = None
+
     def __init__(self, msg, reply=None):
         super(RelayError, self).__init__(msg)
         if reply:
             self.reply = reply
+        else:
+            reply_msg = ' '.join((self._default_esc, msg))
+            self.reply = Reply(self._default_code, reply_msg)
 
 
 class PermanentRelayError(RelayError):
@@ -44,7 +52,9 @@ class PermanentRelayError(RelayError):
     be successfully delivered no matter how many times delivery is attempted.
 
     """
-    pass
+
+    _default_code = '550'
+    _default_esc = '5.0.0'
 
 
 class TransientRelayError(RelayError):
@@ -52,7 +62,9 @@ class TransientRelayError(RelayError):
     successful if tried again later.
 
     """
-    pass
+
+    _default_code = '450'
+    _default_esc = '4.0.0'
 
 
 class Relay(object):
@@ -86,15 +98,36 @@ class Relay(object):
         return self.attempt(envelope, attempts)
 
     def attempt(self, envelope, attempts):
-        """This method must be overriden by sub-classes in order to be passed
+        """This method must be overridden by sub-classes in order to be passed
         in to the |Queue| constructor.
 
+        The result of a successful relay attempt is either ``None`` or a
+        |Reply| object. The result of a failing relay attempt is either a
+        :class:`~slimta.relay.PermanentRelayFailure` or
+        :class:`~slimta.relay.TransientRelayFailure` error.
+
+        If the result applies to the entire ``envelope`` and all its
+        recipients, implementations may return the successful result or raise
+        the failure. If the result is different per-recipient, then
+        implementations may return a dictionary where the key is a recipient
+        from :attr:`~slimta.envelope.Envelope.recipients` and the value is the
+        relay result (successful or failing).
+
         :param envelope: |Envelope| to attempt delivery for.
         :param attempts: Number of times the envelope has attempted delivery.
+        :returns: The relay result, as described above.
         :raises: :class:`PermanentRelayError`, :class:`TransientRelayError`
 
         """
         raise NotImplementedError()
 
+    def kill(self):
+        """This method is used by |Relay| and |Relay|-like objects to properly
+        end associated services (such as running :class:`~gevent.Greenlet`
+        threads) and close resources.
+
+        """
+        pass
+
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
