@@ -31,12 +31,11 @@ from __future__ import absolute_import
 from functools import wraps
 
 import gevent
-import dns.resolver
-from dns.exception import DNSException
 from gevent.pool import Pool, Group
-from gevent.event import Event
+from pycares.errno import ARES_ENOTFOUND
 
-from slimta.smtp.reply import Reply
+from slimta import logging
+from slimta.util.dns import DNSResolver, DNSError
 
 __all__ = ['DnsBlocklist', 'DnsBlocklistGroup', 'check_dnsbl']
 
@@ -48,14 +47,16 @@ class DnsBlocklist(object):
         if '123.4.56.7' in dnsbl:
             reason = dnsbl['123.4.56.7']
 
-    *Note:* Because ``__getitem__`` simply calls :meth:`.get_reason()`, it
-    will never raise a :class:`KeyError` and should only be used after using
-    :meth:`.get()` or ``__contains__``.
+    .. note::
+
+       Because ``__getitem__`` simply calls :meth:`.get_reason()`, it
+       will never raise a :class:`KeyError` and should only be used after using
+       :meth:`.get()` or ``__contains__``.
 
     :param address: The DNSBL domain name.
 
     """
-    
+
     def __init__(self, address):
         self.address = address
 
@@ -69,30 +70,35 @@ class DnsBlocklist(object):
     def __getitem__(self, ip):
         return self.get_reason(ip, timeout=10.0)
 
-    def get(self, ip, timeout=None):
+    def get(self, ip, timeout=None, strict=False):
         """Checks this DNSBL for the given IP address. This method does not
         check the answer, only that the response was not ``NXDOMAIN``.
 
         :param ip: The IP address string to check.
         :param timeout: A timeout in seconds before ``False`` is returned.
-        :returns: ``True`` if the query succeeded and the result was not
-                  ``NXDOMAIN``, ``False`` otherwise.
+        :param strict: If ``True``, DNS exceptions that are not ``NXDOMAIN``
+                       (including timeouts) will also  result in a ``True``
+                       return value.
+        :returns: ``True`` if the DNSBL had an entry for the given IP address,
+                  ``False`` otherwise.
 
         """
         with gevent.Timeout(timeout, None):
             query = self._build_query(ip)
             try:
-                answers = dns.resolver.query(query, 'A')
-            except dns.resolver.NXDOMAIN:
-                return False
+                DNSResolver.query(query, 'A').get()
+            except DNSError as exc:
+                if exc.errno == ARES_ENOTFOUND:
+                    return False
+                logging.log_exception(__name__, query=query)
             else:
                 return True
-        return False
+        return strict
 
     def get_reason(self, ip, timeout=None):
-        """Gets the TXT record for the IP address on this DNSBL. This is usually
-        a reason for why the IP address matched. As such, this function should
-        only be called after :meth:`.get()` returns ``True``.
+        """Gets the TXT record for the IP address on this DNSBL. This is
+        usually a reason for why the IP address matched. As such, this function
+        should only be called after :meth:`.get()` returns ``True``.
 
         :param ip: The IP address to get a match reason for.
         :param timeout: A timeout in seconds before giving up.
@@ -102,13 +108,13 @@ class DnsBlocklist(object):
         with gevent.Timeout(timeout, None):
             query = self._build_query(ip)
             try:
-                answers = dns.resolver.query(query, 'TXT')
-            except DNSException:
+                answers = DNSResolver.query(query, 'TXT').get()
+            except DNSError:
                 pass
             else:
                 if answers:
-                    for txt in answers:
-                        return str(txt)
+                    for rdata in answers:
+                        return rdata.text
 
 
 class DnsBlocklistGroup(object):
@@ -208,8 +214,12 @@ def check_dnsbl(address, match_code='550', match_message='5.7.1 Access denied',
     def new_decorator(f):
         @wraps(f)
         def new_f(self, reply, *args, **kwargs):
-            ip = self.session.address[0]
-            if address.get(ip, timeout=timeout):
+            ip = self.session.address[0] or ''
+            try:
+                ret = address.get(ip, timeout=timeout)
+            except ValueError:
+                ret = None
+            if ret:
                 reply.code = match_code
                 reply.message = match_message
             else:
