@@ -11,6 +11,7 @@ from slimta.smtp import ConnectionLost
 from slimta.relay import TransientRelayError, PermanentRelayError
 from slimta.relay.smtp.lmtpclient import LmtpRelayClient
 from slimta.envelope import Envelope
+from slimta.smtp.reply import Reply
 
 
 class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
@@ -39,7 +40,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
             client._ehlo()
 
     def test_deliver(self):
-        result = self.mox.CreateMock(AsyncResult)
+        result = self.mox.CreateMockAnything()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test \x81\r\n')
         self.sock.sendall(b'LHLO there\r\n')
@@ -52,7 +53,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
         self.sock.recv(IsA(int)).AndReturn(b'354 Go ahead\r\n')
         self.sock.sendall(b'From: sender@example.com\r\n\r\ntest test \x81\r\n.\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
-        result.set({'rcpt@example.com': None})
+        result.set({'rcpt@example.com': Reply('250', 'Ok')})
         self.mox.ReplayAll()
         client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
@@ -60,7 +61,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
         client._deliver(result, env)
 
     def test_deliver_badpipeline(self):
-        result = self.mox.CreateMock(AsyncResult)
+        result = self.mox.CreateMockAnything()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
         self.sock.sendall(b'LHLO there\r\n')
@@ -77,7 +78,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
         client._deliver(result, env)
 
     def test_deliver_multircpt(self):
-        result = self.mox.CreateMock(AsyncResult)
+        result = self.mox.CreateMockAnything()
         env = Envelope('sender@example.com', ['rcpt1@example.com', 'rcpt2@example.com', 'rcpt3@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
         self.sock.sendall(b'LHLO there\r\n')
@@ -86,7 +87,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n250 Ok\r\n550 Nope\r\n250 Ok\r\n354 Go ahead\r\n')
         self.sock.sendall(b'From: sender@example.com\r\n\r\ntest test\r\n.\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n450 Yikes\r\n')
-        result.set({'rcpt1@example.com': None,
+        result.set({'rcpt1@example.com': Reply('250', 'Ok'),
                     'rcpt2@example.com': IsA(PermanentRelayError),
                     'rcpt3@example.com': IsA(TransientRelayError)})
         self.sock.sendall(b'RSET\r\n')
@@ -98,7 +99,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
         client._deliver(result, env)
 
     def test_deliver_badrcpts(self):
-        result = self.mox.CreateMock(AsyncResult)
+        result = self.mox.CreateMockAnything()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
         self.sock.sendall(b'LHLO there\r\n')
@@ -115,7 +116,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
         client._deliver(result, env)
 
     def test_deliver_rset_exception(self):
-        result = self.mox.CreateMock(AsyncResult)
+        result = self.mox.CreateMockAnything()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
         self.sock.sendall(b'LHLO there\r\n')
@@ -133,7 +134,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
             client._deliver(result, env)
 
     def test_deliver_conversion(self):
-        result = self.mox.CreateMock(AsyncResult)
+        result = self.mox.CreateMockAnything()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test \x81\r\n')
         self.sock.sendall(b'LHLO there\r\n')
@@ -145,7 +146,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
         else:
             self.sock.sendall(b'From: sender@example.com\r\nContent-Transfer-Encoding: base64\r\n\r\ndGVzdCB0ZXN0IIENCg==\r\n.\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
-        result.set({'rcpt@example.com': None})
+        result.set({'rcpt@example.com': Reply('250', 'Ok')})
         self.mox.ReplayAll()
         client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there', binary_encoder=encode_base64)
         client._connect()
@@ -153,7 +154,7 @@ class TestLmtpRelayClient(MoxTestBase, unittest.TestCase):
         client._deliver(result, env)
 
     def test_deliver_conversion_failure(self):
-        result = self.mox.CreateMock(AsyncResult)
+        result = self.mox.CreateMockAnything()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test \x81\r\n')
         self.sock.sendall(b'LHLO there\r\n')
